==> opensimcreator-0.3.2-src.tar.xz: opensim-creator_0.3.2/src/OpenSimBindings/IntegratorMethod.cpp <==
#include "IntegratorMethod.hpp"

#include "src/Utils/Algorithms.hpp"

#include <nonstd/span.hpp>
#include <simmath/ExplicitEulerIntegrator.h>
#include <simmath/RungeKutta2Integrator.h>
#include <simmath/RungeKutta3Integrator.h>
#include <simmath/RungeKuttaFeldbergIntegrator.h>
#include <simmath/RungeKuttaMersonIntegrator.h>
#include <simmath/SemiExplicitEuler2Integrator.h>
#include <simmath/VerletIntegrator.h>

#include <array>
#include <cstddef>
#include <memory>

static constexpr auto c_IntegratorMethods = osc::MakeSizedArray<osc::IntegratorMethod, static_cast<size_t>(osc::IntegratorMethod::TOTAL)>
(
    osc::IntegratorMethod::OpenSimManagerDefault,
    osc::IntegratorMethod::ExplicitEuler,
    osc::IntegratorMethod::RungeKutta2,
    osc::IntegratorMethod::RungeKutta3,
    osc::IntegratorMethod::RungeKuttaFeldberg,
    osc::IntegratorMethod::RungeKuttaMerson,
    osc::IntegratorMethod::SemiExplicitEuler2,
    osc::IntegratorMethod::Verlet
);

static constexpr auto c_IntegratorMethodStrings = osc::MakeSizedArray<char const*, static_cast<size_t>(osc::IntegratorMethod::TOTAL)>
(
    "OpenSim::Manager Default",
    "Explicit Euler",
    "Runge Kutta 2",
    "Runge Kutta 3",
    "Runge Kutta Feldberg",
    "Runge Kutta Merson",
    "Semi Explicit Euler 2",
    "Verlet"
);

nonstd::span<osc::IntegratorMethod const> osc::GetAllIntegratorMethods()
{
    return c_IntegratorMethods;
}

nonstd::span<char const* const> osc::GetAllIntegratorMethodStrings()
{
    return c_IntegratorMethodStrings;
}

char const* osc::GetIntegratorMethodString(IntegratorMethod im)
{
    return GetAllIntegratorMethodStrings()[static_cast<size_t>(im)];
}

std::unique_ptr<SimTK::Integrator> osc::CreateIntegrator(SimTK::System const& system, osc::IntegratorMethod method)
{
    switch (method) {
    case osc::IntegratorMethod::OpenSimManagerDefault:
        return std::make_unique<SimTK::RungeKuttaMersonIntegrator>(system);
    case osc::IntegratorMethod::ExplicitEuler:
        return std::make_unique<SimTK::ExplicitEulerIntegrator>(system);
    case osc::IntegratorMethod::RungeKutta2:
        return std::make_unique<SimTK::RungeKutta2Integrator>(system);
    case osc::IntegratorMethod::RungeKutta3:
        return std::make_unique<SimTK::RungeKutta3Integrator>(system);
    case osc::IntegratorMethod::RungeKuttaFeldberg:
        return std::make_unique<SimTK::RungeKuttaFeldbergIntegrator>(system);
    case osc::IntegratorMethod::RungeKuttaMerson:
        return std::make_unique<SimTK::RungeKuttaMersonIntegrator>(system);
    case osc::IntegratorMethod::SemiExplicitEuler2:
        return std::make_unique<SimTK::SemiExplicitEuler2Integrator>(system);
    case osc::IntegratorMethod::Verlet:
        return std::make_unique<SimTK::VerletIntegrator>(system);
    default:
        return std::make_unique<SimTK::RungeKuttaMersonIntegrator>(system);
    }
}

==> opensimcreator-0.4.0-src.tar.xz: opensim-creator_0.4.0/src/OpenSimBindings/IntegratorMethod.cpp <==
#include "IntegratorMethod.hpp"

#include "src/Utils/Algorithms.hpp"
#include "src/Utils/CStringView.hpp"

#include <nonstd/span.hpp>
#include <simmath/ExplicitEulerIntegrator.h>
#include <simmath/RungeKutta2Integrator.h>
#include <simmath/RungeKutta3Integrator.h>
#include <simmath/RungeKuttaFeldbergIntegrator.h>
#include <simmath/RungeKuttaMersonIntegrator.h>
#include <simmath/SemiExplicitEuler2Integrator.h>
#include <simmath/VerletIntegrator.h>

#include <array>
#include <cstddef>
#include <memory>

static auto constexpr c_IntegratorMethods = osc::MakeSizedArray<osc::IntegratorMethod, static_cast<size_t>(osc::IntegratorMethod::TOTAL)>
(
    osc::IntegratorMethod::OpenSimManagerDefault,
    osc::IntegratorMethod::ExplicitEuler,
    osc::IntegratorMethod::RungeKutta2,
    osc::IntegratorMethod::RungeKutta3,
    osc::IntegratorMethod::RungeKuttaFeldberg,
    osc::IntegratorMethod::RungeKuttaMerson,
    osc::IntegratorMethod::SemiExplicitEuler2,
    osc::IntegratorMethod::Verlet
);

static auto constexpr c_IntegratorMethodStrings = osc::MakeSizedArray<osc::CStringView, static_cast<size_t>(osc::IntegratorMethod::TOTAL)>
(
    "OpenSim::Manager Default",
    "Explicit Euler",
    "Runge Kutta 2",
    "Runge Kutta 3",
    "Runge Kutta Feldberg",
    "Runge Kutta Merson",
    "Semi Explicit Euler 2",
    "Verlet"
);

nonstd::span<osc::IntegratorMethod const> osc::GetAllIntegratorMethods()
{
    return c_IntegratorMethods;
}

nonstd::span<osc::CStringView const> osc::GetAllIntegratorMethodStrings()
{
    return c_IntegratorMethodStrings;
}

osc::CStringView osc::GetIntegratorMethodString(IntegratorMethod im)
{
    return GetAllIntegratorMethodStrings()[static_cast<size_t>(im)];
}

std::unique_ptr<SimTK::Integrator> osc::CreateIntegrator(SimTK::System const& system, osc::IntegratorMethod method)
{
    switch (method) {
    case osc::IntegratorMethod::OpenSimManagerDefault:
        return std::make_unique<SimTK::RungeKuttaMersonIntegrator>(system);
    case osc::IntegratorMethod::ExplicitEuler:
        return std::make_unique<SimTK::ExplicitEulerIntegrator>(system);
    case osc::IntegratorMethod::RungeKutta2:
        return std::make_unique<SimTK::RungeKutta2Integrator>(system);
    case osc::IntegratorMethod::RungeKutta3:
        return std::make_unique<SimTK::RungeKutta3Integrator>(system);
    case osc::IntegratorMethod::RungeKuttaFeldberg:
        return std::make_unique<SimTK::RungeKuttaFeldbergIntegrator>(system);
    case osc::IntegratorMethod::RungeKuttaMerson:
        return std::make_unique<SimTK::RungeKuttaMersonIntegrator>(system);
    case osc::IntegratorMethod::SemiExplicitEuler2:
        return std::make_unique<SimTK::SemiExplicitEuler2Integrator>(system);
    case osc::IntegratorMethod::Verlet:
        return std::make_unique<SimTK::VerletIntegrator>(system);
    default:
        return std::make_unique<SimTK::RungeKuttaMersonIntegrator>(system);
    }
}
